@@ -9,7 +9,9 @@ from typing import Optional, List, Dict, Iterator, Type, KeysView, Union, cast,
 from logging import Logger
 
 from pydantic import BaseModel, ByteSize, Field, ValidationError, parse_obj_as
+from pydantic.schema import model_schema
 
+from .version import version
 from .exception import PipelineError, PipelineInputError, PipelineOutputError
 from .message import Message, Command, Log, Kind, MessageBase
 from .monitor import WorkerMonitor as Monitor
@@ -27,34 +29,33 @@ class CommandActions(str, Enum):
     Define = "DEFINE"
 
 
-class DefinitionInternal(BaseModel):
-    """ """
-
-    name: str
-    version: str
-    description: str
-    source: SourceSettings
-    destination: DestinationSettings
-    input_schema: Dict[str, Any] = dict()
-    output_schema: Dict[str, Any] = dict()
-
-
-class TapSettings(BaseModel):
-    namespace: Optional[str]
-    topic: str
-
-
 class Definition(BaseModel):
     """ """
 
     name: str
     version: str
     description: str
-    source: TapSettings
-    destination: TapSettings
+    source: Optional[Dict]
+    destination: Optional[Dict]
     input_schema: Dict[str, Any] = dict()
     output_schema: Dict[str, Any] = dict()
 
+    @classmethod
+    def new(cls, **data):
+        if "input_class" in data:
+            input_class = data.get("input_class")
+            input_schema = model_schema(input_class, ref_prefix="#/components/schemas")
+            del data["input_class"]
+            data["input_schema"] = input_schema
+        if "output_class" in data:
+            output_class = data.get("output_class")
+            output_schema = model_schema(
+                output_class, ref_prefix="#/components/schemas"
+            )
+            del data["output_class"]
+            data["output_schema"] = output_schema
+        return cls(**data)
+
 
 class WorkerType(IntEnum):
     Normal = 0
@@ -91,7 +92,9 @@ class Worker(ABC):
 
         self.monitor = Monitor(self)
 
-        self.logger.info("Pipeline Worker %s (%s)", self.name, self.version)
+        self.logger.info(
+            f"Pipeline Worker {self.name} {self.version} (pipeline {version})"
+        )
 
     def setup(self) -> None:
         """loading code goes here"""
@@ -435,7 +438,6 @@ class Processor(Worker):
             self.logger.exception(
                 f"Input validation failed for message {msg}", exc_info=e
             )
-            self.logger.error(msg.json())
             raise PipelineInputError(f"Input validation failed for message {msg}")
 
         try:
@@ -471,15 +473,15 @@ class Processor(Worker):
                 "version": self.version,
                 "description": self.description,
             }
-            dct["source"] = self.source.settings
+            dct["source"] = self.source.settings.dict()
             if self.has_output():
-                dct["destination"] = self.destination.settings
+                dct["destination"] = self.destination.settings.dict()
             if self.input_class:
-                dct["input_schema"] = self.input_class.schema()
+                dct["input_class"] = self.input_class
             if self.output_class:
-                dct["output_schema"] = self.output_class.schema()
+                dct["output_class"] = self.output_class
 
-            definition = DefinitionInternal(**dct)
+            definition = Definition.new(**dct)
             updated = cmd.update_content(definition)
         else:
             raise PipelineInputError("Unknown command")
